package com.ruoyi.frequency.userappmessage.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.frequency.userappmessage.entity.UserAppMessage;

import java.util.List;

/**
 * 用户已读消息Mapper接口
 * 
 * @author liwenlong
 * @date 2023-07-20
 */
public interface UserAppMessageMapper  extends BaseMapper<UserAppMessage>
{
    /**
     * 查询用户已读消息
     * 
     * @param id 用户已读消息主键
     * @return 用户已读消息
     */
    UserAppMessage selectUserAppMessageById(Long id);

    /**
     * 查询用户已读消息列表
     * 
     * @param userAppMessage 用户已读消息
     * @return 用户已读消息集合
     */
    List<UserAppMessage> selectUserAppMessageList(UserAppMessage userAppMessage);

    /**
     * 新增用户已读消息
     * 
     * @param userAppMessage 用户已读消息
     * @return 结果
     */
    int insertUserAppMessage(UserAppMessage userAppMessage);

    /**
     * 修改用户已读消息
     * 
     * @param userAppMessage 用户已读消息
     * @return 结果
     */
    int updateUserAppMessage(UserAppMessage userAppMessage);

    /**
     * 删除用户已读消息
     * 
     * @param id 用户已读消息主键
     * @return 结果
     */
    int deleteUserAppMessageById(Long id);

    /**
     * 批量删除用户已读消息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteUserAppMessageByIds(Long[] ids);
}
